aboutsummaryrefslogtreecommitdiffstats
path: root/capture_info.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2014-05-23 10:50:02 +0000
committerGuy Harris <guy@alum.mit.edu>2014-05-23 10:50:10 +0000
commita344c9736efe5519543da1290e1ad9065d0b0cff (patch)
tree7757d80d74ae710e5d4e4a1b0cb638d0ec644fc4 /capture_info.h
parent716fdc8e398ea7435b23192ab1f7d59e7b21e32b (diff)
Revert "Allow wtap_read() and wtap_seek_read() to return non-packet records."
This reverts commit c0c480d08c175eed4524ea9e73ec86298f468cf4. A better way to do this is to have the record type be part of struct wtap_pkthdr; that keeps the metadata for the record together and requires fewer API changes. That is in-progress. Change-Id: Ic558f163a48e2c6d0df7f55e81a35a5e24b53bc6 Reviewed-on: https://code.wireshark.org/review/1741 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'capture_info.h')
-rw-r--r--capture_info.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/capture_info.h b/capture_info.h
index 286dce12c0..3e5845ac6c 100644
--- a/capture_info.h
+++ b/capture_info.h
@@ -43,8 +43,8 @@ extern void capture_info_open(capture_session *cap_session);
/* new file arrived - (eventually close old wtap), open wtap */
extern gboolean capture_info_new_file(const char *new_filename);
-/* new records arrived - read from wtap, count */
-extern void capture_info_new_records(int to_read);
+/* new packets arrived - read from wtap, count */
+extern void capture_info_new_packets(int to_read);
/* close the info - close wtap, destroy dialog */
extern void capture_info_close(void);